@@ -1,6 +1,6 @@
 import lvlspy.properties as lp
 import numpy as np
-from astropy import units as u
+from gslconsts.consts import *
 
 units_dict = {"eV": 1000, "keV": 1, "MeV": 1.0e-3, "GeV": 1.0e-6}
 
@@ -98,8 +98,9 @@ class Level(lp.Properties):
             multiplicity * exp(-Energy/kT).
 
         """
+        # the factor of 1e+3 is to convert the energy to keV.
+        k_BT = GSL_CONST_CGSM_BOLTZMANN * T
 
-        T_K = T * u.K
-        T_keV = T_K.to(u.keV, equivalencies=u.temperature_energy())
+        E = 1.0e3 * GSL_CONST_CGSM_ELECTRON_VOLT * self.energy
 
-        return self.multiplicity * np.exp(-self.energy / T_keV.value)
+        return self.multiplicity * np.exp(-E / k_BT)
